# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..graphic.x_graphic import XGraphic as XGraphic_a4da0afc
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..io.x_output_stream import XOutputStream as XOutputStream_a4e00b35

class XGraphicStorageHandler(XInterface_8f010a43):
    """
    interface for loading, saving and serializing of XGraphic objects to a document storage
    
    **since**
    
        LibreOffice 6.1

    See Also:
        `API XGraphicStorageHandler <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XGraphicStorageHandler.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XGraphicStorageHandler']

    def createInputStream(self, xGraphic: 'XGraphic_a4da0afc') -> 'XInputStream_98d40ab4':
        """
        create an input stream from the input graphic
        """
    def loadGraphic(self, aURL: str) -> 'XGraphic_a4da0afc':
        """
        load a graphic defined by the URL from the storage
        """
    def loadGraphicFromOutputStream(self, xOutputStream: 'XOutputStream_a4e00b35') -> 'XGraphic_a4da0afc':
        """
        load a graphic from the output stream
        """
    def saveGraphic(self, xGraphic: 'XGraphic_a4da0afc') -> str:
        """
        save the graphic to the storage and return the URL reference to its location inside the storage
        """
    def saveGraphicByName(self, xGraphic: 'XGraphic_a4da0afc', savedMimeType: str, aRequestedName: str) -> str:
        """
        save the graphic to the storage with a requested name and return the URL reference to its location inside the storage and the mime type of the format that the graphic was saved to as an output parameter

        * ``savedMimeType`` is an out direction argument.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xsd
from typing_extensions import Literal
"""
Const

These constants specify the class used of an XDataType.

See Also:
    `API DataTypeClass <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1xsd_1_1DataTypeClass.html>`_
"""
STRING: Literal[1]
"""
specifies an XSD compliant string type
"""
BOOLEAN: Literal[2]
"""
specifies an XSD compliant boolean type
"""
DECIMAL: Literal[3]
"""
specifies an XSD compliant decimal type
"""
FLOAT: Literal[4]
"""
specifies an XSD compliant float type
"""
DOUBLE: Literal[5]
"""
specifies an XSD compliant double type
"""
DURATION: Literal[6]
"""
specifies an XSD compliant duration type
"""
DATETIME: Literal[7]
"""
specifies an XSD compliant datetime type
"""
TIME: Literal[8]
"""
specifies an XSD compliant time type
"""
DATE: Literal[9]
"""
specifies an XSD compliant date type
"""
gYearMonth: Literal[10]
"""
specifies an XSD compliant gYearMonth type
"""
gYear: Literal[11]
"""
specifies an XSD compliant gYear type
"""
gMonthDay: Literal[12]
"""
specifies an XSD compliant gMonthDay type
"""
gDay: Literal[13]
"""
specifies an XSD compliant gDay type
"""
gMonth: Literal[14]
"""
specifies an XSD compliant gMonth type
"""
hexBinary: Literal[15]
"""
specifies an XSD compliant hexBinary type
"""
base64Binary: Literal[16]
"""
specifies an XSD compliant base64Binary type
"""
anyURI: Literal[17]
"""
specifies an XSD compliant anyURI type
"""
QName: Literal[18]
"""
specifies an XSD compliant QName type
"""
NOTATION: Literal[19]
"""
specifies an XSD compliant NOTATION type
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.xml.crypto
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .security_operation_status import SecurityOperationStatus as SecurityOperationStatus_b66e12b5
    from ..wrapper.xxml_element_wrapper import XXMLElementWrapper as XXMLElementWrapper_66c0107c

class XXMLSecurityTemplate(XInterface_8f010a43):
    """
    Interface of the XML security template.
    
    This interface represents a security template, which is the super interface of the XXMLSignatureTemplate interface and the XXMLEncryptionTemplate interface.

    See Also:
        `API XXMLSecurityTemplate <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1xml_1_1crypto_1_1XXMLSecurityTemplate.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.xml.crypto.XXMLSecurityTemplate']

    def getStatus(self) -> 'SecurityOperationStatus_b66e12b5':
        """
        Get the template status.
        """
    def getTemplate(self) -> 'XXMLElementWrapper_66c0107c':
        """
        Get the XML signature element that represents the signature template.
        """
    def setStatus(self, status: 'SecurityOperationStatus_b66e12b5') -> None:
        """
        Set the template status.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setTarget(self, aXmlElement: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Load the target XML element, i.e.
        
        the element to be signed

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def setTemplate(self, aXmlElement: 'XXMLElementWrapper_66c0107c') -> None:
        """
        Load a XML signature template from XML signature element.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.chart
from typing_extensions import Literal
"""
Const

These values specify the type of the symbol used for data points.

This only applies to diagrams that use symbols like line diagrams.

The default symbols are currently:

See Also:
    `API ChartSymbolType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1chart_1_1ChartSymbolType.html>`_
"""
NONE: Literal[-3]
"""
No symbol is used.
"""
AUTO: Literal[-2]
"""
The symbol is selected automatically.

The size of symbol will be dynamic and the type depends on the data row number.
"""
BITMAPURL: Literal[-1]
"""
Take a Bitmap from a URL and use this as symbol.

The bitmap given by the URL set in the property ChartDataPointProperties.SymbolBitmapURL is copied so that the graphic is embedded.
"""
SYMBOL0: Literal[0]
"""
The default symbol for row 0 is used.
"""
SYMBOL1: Literal[1]
"""
The default symbol for row 1 is used.
"""
SYMBOL2: Literal[2]
"""
The default symbol for row 2 is used.
"""
SYMBOL3: Literal[3]
"""
The default symbol for row 3 is used.
"""
SYMBOL4: Literal[4]
"""
The default symbol for row 4 is used.
"""
SYMBOL5: Literal[5]
"""
The default symbol for row 5 is used.
"""
SYMBOL6: Literal[6]
"""
The default symbol for row 6 is used.
"""
SYMBOL7: Literal[7]
"""
The default symbol for row 7 is used.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Exception Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.script.provider
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ...uno.exception import Exception as Exception_85530a09
from ...uno.x_interface import XInterface as XInterface_8f010a43

class ScriptErrorRaisedException(Exception_85530a09):
    """
    Exception Class

    is a checked exception that represents an error encountered by a LanguageScriptProvider whilst executing a script

    See Also:
        `API ScriptErrorRaisedException <https://api.libreoffice.org/docs/idl/ref/exceptioncom_1_1sun_1_1star_1_1script_1_1provider_1_1ScriptErrorRaisedException.html>`_
    """

    typeName: Literal['com.sun.star.script.provider.ScriptErrorRaisedException']

    def __init__(self, Message: typing.Optional[str] = ..., Context: typing.Optional[XInterface_8f010a43] = ..., scriptName: typing.Optional[str] = ..., language: typing.Optional[str] = ..., lineNum: typing.Optional[int] = ...) -> None:
        """
        Constructor

        Arguments:
            Message (str, optional): Message value.
            Context (XInterface, optional): Context value.
            scriptName (str, optional): scriptName value.
            language (str, optional): language value.
            lineNum (int, optional): lineNum value.
        """
    @property
    def scriptName(self) -> str:
        """
        Name of script where error occurred.
        """

    @property
    def language(self) -> str:
        """
        Scripting language of script that generated exception.
        """

    @property
    def lineNum(self) -> int:
        """
        line number where error occurred.
        """


__all__ = ['ScriptErrorRaisedException']




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..table.x_cell import XCell as XCell_70d408e8
    from .x_document_index import XDocumentIndex as XDocumentIndex_c9330c5c
    from .x_document_index_mark import XDocumentIndexMark as XDocumentIndexMark_fe490de7
    from .x_footnote import XFootnote as XFootnote_901e0a73
    from .x_text_content import XTextContent as XTextContent_b16e0ba5
    from .x_text_frame import XTextFrame as XTextFrame_9a7e0ab5
    from .x_text_section import XTextSection as XTextSection_b1730b9f
    from .x_text_table import XTextTable as XTextTable_9a810ab2

class TextRangeContentProperties(ABC):
    """
    Service Class

    describes the structural properties to retrieve text contents.
    
    **since**
    
        OOo 3.3

    See Also:
        `API TextRangeContentProperties <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextRangeContentProperties.html>`_
    """
    @property
    def Cell(self) -> 'XCell_70d408e8':
        """
        may contain a table cell.
        """
    @property
    def DocumentIndex(self) -> 'XDocumentIndex_c9330c5c':
        """
        may contain a document index.
        """
    @property
    def DocumentIndexMark(self) -> 'XDocumentIndexMark_fe490de7':
        """
        may contain a document index mark.
        """
    @property
    def Endnote(self) -> 'XFootnote_901e0a73':
        """
        may contain an endnote.
        """
    @property
    def Footnote(self) -> 'XFootnote_901e0a73':
        """
        may contain a footnote.
        """
    @property
    def NestedTextContent(self) -> 'XTextContent_b16e0ba5':
        """
        may contain a nested text content.
        
        For example, may contain an InContentMetadata or a com.sun.star.text.textfield.MetadataField.
        """
    @property
    def ReferenceMark(self) -> 'XTextContent_b16e0ba5':
        """
        may contain a reference mark.
        """
    @property
    def TextFrame(self) -> 'XTextFrame_9a7e0ab5':
        """
        may contain a text frame.
        """
    @property
    def TextParagraph(self) -> 'XTextContent_b16e0ba5':
        """
        Paragraph for the start of this range.
        
        **since**
        
            LibreOffice 6.0
        """
    @property
    def TextSection(self) -> 'XTextSection_b1730b9f':
        """
        may contain a text section.
        """
    @property
    def TextTable(self) -> 'XTextTable_9a810ab2':
        """
        may contain a text table.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.linguistic2
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..beans.property_value import PropertyValue as PropertyValue_c9610c73
from ..lang.locale import Locale as Locale_70d308fa
from .single_proofreading_error import SingleProofreadingError as SingleProofreadingError_c54812c1
from .x_proofreader import XProofreader as XProofreader_dab0e46
from ..text.x_flat_paragraph import XFlatParagraph as XFlatParagraph_c8310c42


class ProofreadingResult(object):
    """
    Struct Class

    holds the results from proofreading a sentence.
    
    **since**
    
        OOo 3.0.1

    See Also:
        `API ProofreadingResult <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1linguistic2_1_1ProofreadingResult.html>`_
    """
    typeName: Literal['com.sun.star.linguistic2.ProofreadingResult']

    def __init__(self, aErrors: typing.Optional[typing.Tuple[SingleProofreadingError_c54812c1, ...]] = ..., aProperties: typing.Optional[typing.Tuple[PropertyValue_c9610c73, ...]] = ..., aDocumentIdentifier: typing.Optional[str] = ..., xFlatParagraph: typing.Optional[XFlatParagraph_c8310c42] = ..., aText: typing.Optional[str] = ..., aLocale: typing.Optional[Locale_70d308fa] = ..., nStartOfSentencePosition: typing.Optional[int] = ..., nBehindEndOfSentencePosition: typing.Optional[int] = ..., nStartOfNextSentencePosition: typing.Optional[int] = ..., xProofreader: typing.Optional[XProofreader_dab0e46] = ...) -> None:
        """
        Constructor

        Arguments:
            aErrors (typing.Tuple[SingleProofreadingError, ...], optional): aErrors value.
            aProperties (typing.Tuple[PropertyValue, ...], optional): aProperties value.
            aDocumentIdentifier (str, optional): aDocumentIdentifier value.
            xFlatParagraph (XFlatParagraph, optional): xFlatParagraph value.
            aText (str, optional): aText value.
            aLocale (Locale, optional): aLocale value.
            nStartOfSentencePosition (int, optional): nStartOfSentencePosition value.
            nBehindEndOfSentencePosition (int, optional): nBehindEndOfSentencePosition value.
            nStartOfNextSentencePosition (int, optional): nStartOfNextSentencePosition value.
            xProofreader (XProofreader, optional): xProofreader value.
        """


    @property
    def aErrors(self) -> typing.Tuple[SingleProofreadingError_c54812c1, ...]:
        ...


    @property
    def aProperties(self) -> typing.Tuple[PropertyValue_c9610c73, ...]:
        ...


    @property
    def aDocumentIdentifier(self) -> str:
        ...


    @property
    def xFlatParagraph(self) -> XFlatParagraph_c8310c42:
        ...


    @property
    def aText(self) -> str:
        ...


    @property
    def aLocale(self) -> Locale_70d308fa:
        ...


    @property
    def nStartOfSentencePosition(self) -> int:
        ...


    @property
    def nBehindEndOfSentencePosition(self) -> int:
        ...


    @property
    def nStartOfNextSentencePosition(self) -> int:
        ...


    @property
    def xProofreader(self) -> XProofreader_dab0e46:
        ...





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from ..container.x_name_access import XNameAccess as XNameAccess_e2ab0cf6
    from ..io.x_input_stream import XInputStream as XInputStream_98d40ab4
    from ..sdbc.x_array import XArray as XArray_708108fb
    from ..sdbc.x_blob import XBlob as XBlob_6773087b
    from ..sdbc.x_clob import XClob as XClob_6777087c
    from ..sdbc.x_ref import XRef as XRef_5f110819
    from ..util.date import Date as Date_60040844
    from ..util.date_time import DateTime as DateTime_84de09d3
    from ..util.time import Time as Time_604e0855

class XColumn(XInterface_8f010a43):
    """
    is used to access data which is collected in a row.

    See Also:
        `API XColumn <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XColumn.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XColumn']

    def getArray(self) -> 'XArray_708108fb':
        """
        gets a SQL ARRAY value from the current row.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getBinaryStream(self) -> 'XInputStream_98d40ab4':
        """
        gets the value of a column in the current row as a stream of uninterpreted bytes.
        
        The value can then be read in chunks from the stream. This method is particularly suitable for retrieving large LONGVARBINARY or LONGVARCHAR values.
        
        Note: All the data in the returned stream must be read prior to getting the value of any other column. The next call to a get method implicitly closes the stream. Also, a stream may return 0 when the method com.sun.star.io.XInputStream.available() is called whether there is data available or not.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getBlob(self) -> 'XBlob_6773087b':
        """
        gets a BLOB (Binary Large OBject) value in the current row.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getBoolean(self) -> bool:
        """
        gets the value of a column in the current row as boolean.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getByte(self) -> int:
        """
        gets the value of a column in the current row as a byte.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getBytes(self) -> 'typing.Tuple[int, ...]':
        """
        gets the value of a column in the current row as a byte array.
        
        The bytes represent the raw values returned by the driver.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getCharacterStream(self) -> 'XInputStream_98d40ab4':
        """
        gets the value of a column in the current row as a stream of uninterpreted bytes.
        
        The value can then be read in chunks from the stream. This method is particularly suitable for retrieving large LONGVARCHAR values.
        
        Note: All the data in the returned stream must be read prior to getting the value of any other column. The next call to a get method implicitly closes the stream. Also, a stream may return 0 when the method com.sun.star.io.XInputStream.available() is called whether there is data available or not.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getClob(self) -> 'XClob_6777087c':
        """
        gets a CLOB value in the current row of this ResultSet object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getDate(self) -> 'Date_60040844':
        """
        gets the value of a column in the current row as a date object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getDouble(self) -> float:
        """
        gets the value of a column in the current row as a double.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getFloat(self) -> float:
        """
        gets the value of a column in the current row as a float.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getInt(self) -> int:
        """
        gets the value of a column in the current row as a long.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getLong(self) -> int:
        """
        gets the value of a column in the current row as a hyper.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getObject(self, typeMap: 'XNameAccess_e2ab0cf6') -> object:
        """

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getRef(self) -> 'XRef_5f110819':
        """
        gets a REF(<structured-type&gt) column value from the current row.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getShort(self) -> int:
        """
        gets the value of a column in the current row as a short.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getString(self) -> str:
        """
        gets the value of a column in the current row as a String.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getTime(self) -> 'Time_604e0855':
        """
        gets the value of a column in the current row as a time object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def getTimestamp(self) -> 'DateTime_84de09d3':
        """
        gets the value of a column in the current row as a datetime object.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """
    def wasNull(self) -> bool:
        """
        reports whether the last column read had a value of SQL NULL.
        
        Note that you must first call getXXX on a column to try to read its value and then call wasNull() to see if the value read was SQL NULL.

        Raises:
            com.sun.star.sdbc.SQLException: ``SQLException``
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API TextFitToSizeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780a>`_
"""

ALLLINES: 'uno.Enum'
"""
Nowadays this is the same as PROPORTIONAL.
"""
AUTOFIT: 'uno.Enum'
"""
The font size is scaled down (never up!) isotropically to fit the available space.

Auto line-breaks will keep working.
"""
NONE: 'uno.Enum'
"""
the area is not filled.

The text size is only defined by the font properties.

Don't animate this text.

the line is hidden.

the joint between lines will not be connected

the line has no special end.
"""
PROPORTIONAL: 'uno.Enum'
"""
The bitmap with the rendered glyphs is scaled up or down proportionally to fit the size of the shape.

This may scale anisotropically. No AutoGrow and no Auto line-breaks in this case.

On fontwork custom shapes, the rendering is different: each line of text is separately scaled proportionally to fit the width.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.logging
from typing_extensions import Literal
"""
Const

specifies levels to distinguish between severities of logged events

**since**

    OOo 2.3

See Also:
    `API LogLevel <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1logging_1_1LogLevel.html>`_
"""
OFF: Literal[2147483647]
"""
specifies that no messages are to be logged at all

This level can be set at an XLogger to completely prevent logging. You will usually not use it with a concrete log event.
"""
SEVERE: Literal[1000]
"""
denotes a serious failure to be logged
"""
WARNING: Literal[900]
"""
denotes a potential problem to be logged
"""
INFO: Literal[800]
"""
denotes an informational message to be logged
"""
CONFIG: Literal[700]
"""
denotes a static configuration message to be logged
"""
FINE: Literal[500]
"""
denotes basic tracing information to be logged
"""
FINER: Literal[400]
"""
denotes more fine-grained tracing information to be logged
"""
FINEST: Literal[300]
"""
denotes highly detailed tracing information to be logged
"""
ALL: Literal[-2147483648]
"""
specifies that all messages should be logged

This level can be set at an XLogger to enable logging of absolutely all events. You will usually not use it with a concrete log event.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt.grid
from ..uno_control import UnoControl as UnoControl_8f2c0a67
from .x_grid_control import XGridControl as XGridControl_df2e0ce7
from .x_grid_row_selection import XGridRowSelection as XGridRowSelection_25440ee4

class UnoControlGrid(UnoControl_8f2c0a67, XGridControl_df2e0ce7, XGridRowSelection_25440ee4):
    """
    Service Class

    A control that displays a set of tabular data.
    
    The horizontal structure of the grid is defined by the XGridColumnModel implemented in DefaultGridColumnModel The XGridColumn implemented in GridColumn describes the properties and behavior of a single column. Use the XGridColumnModel.addColumn() to add a column to the column model.
    
    All row data are stored in the XGridDataModel. Use the DefaultGridDataModel to add XGridDataModel.addRow() or remove XGridDataModel.removeRow() rows.
    
    The column and data model must be set at the UnoControlGridModel.ColumnModel and UnoControlGridModel.GridDataModel properties.
    
    If you are interested in knowing when the selection changes implement a XGridSelectionListener and add the instance with the method XGridRowSelection.addSelectionListener(). You than will be notified for any selection change.
    
    **since**
    
        OOo 3.3

    See Also:
        `API UnoControlGrid <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1awt_1_1grid_1_1UnoControlGrid.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from .definition_content import DefinitionContent as DefinitionContent_e0d20d25
from .x_sub_document import XSubDocument as XSubDocument_a2da0b02

class DocumentDefinition(DefinitionContent_e0d20d25, XPropertySet_bc180bfa, XSubDocument_a2da0b02):
    """
    Service Class

    specifies a sub document of an OfficeDatabaseDocument.
    
    Usual instances of a DocumentDefinition are forms and reports.
    
    Note that the DocumentDefinition does not denote the actual document (i.e. an object supporting the com.sun.star.frame.XModel interface), but only a shortcut to access and load those actual documents.

    See Also:
        `API DocumentDefinition <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1sdb_1_1DocumentDefinition.html>`_
    """
    @property
    def AsTemplate(self) -> bool:
        """
        Indicates if the document is to be used as template, for example, if a report is to be filled with data.
        """
    @property
    def Name(self) -> str:
        """
        is the name of the document.
        
        If the document is part of the container, it is not possible to alter the name.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..script.x_storage_based_library_container import XStorageBasedLibraryContainer as XStorageBasedLibraryContainer_d72a1321

class XEmbeddedScripts(ABC):
    """
    is supported by OfficeDocuments which allow to embed scripts
    
    **since**
    
        OOo 2.4

    See Also:
        `API XEmbeddedScripts <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XEmbeddedScripts.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XEmbeddedScripts']

    @property
    def AllowMacroExecution(self) -> bool:
        """
        determines whether executing macros from this document is allowed.
        
        Effectively, this attribute is an evaluation of the document's MacroExecMode against possibly applicable configuration settings, the document location in relation to the trusted location, and the like.
        """

    @property
    def BasicLibraries(self) -> 'XStorageBasedLibraryContainer_d72a1321':
        """
        is the container of StarBasic macro libraries contained in the document
        """

    @property
    def DialogLibraries(self) -> 'XStorageBasedLibraryContainer_d72a1321':
        """
        is the container of dialogs libraries contained in the document
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.rendering
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from ..geometry.real_size2_d import RealSize2D as RealSize2D_ca1a0c09


class AnimationAttributes(object):
    """
    Struct Class

    This structure contains attributes needed to run an animation.
    
    **since**
    
        OOo 2.0

    See Also:
        `API AnimationAttributes <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1rendering_1_1AnimationAttributes.html>`_
    """
    typeName: Literal['com.sun.star.rendering.AnimationAttributes']

    def __init__(self, Duration: typing.Optional[float] = ..., RepeatMode: typing.Optional[int] = ..., UntransformedSize: typing.Optional[RealSize2D_ca1a0c09] = ...) -> None:
        """
        Constructor

        Arguments:
            Duration (float, optional): Duration value.
            RepeatMode (int, optional): RepeatMode value.
            UntransformedSize (RealSize2D, optional): UntransformedSize value.
        """


    @property
    def Duration(self) -> float:
        """
        Preferred duration of the animation sequence in seconds.
        """


    @property
    def RepeatMode(self) -> int:
        """
        Repeat mode of the animation sequence.
        
        This value determines how the [0,1] parameter space of the animation should be swept through. Permissible values are given in AnimationRepeat.
        """


    @property
    def UntransformedSize(self) -> RealSize2D_ca1a0c09:
        """
        Size of the untransformed animation sequence.
        
        This value specifies the size of the animation when rendered with the identity view transform. This permits e.g. XSprite implementations to cache rendered animation content in finite-sized bitmaps.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Const
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.i18n
from typing_extensions import Literal


class UnicodeType(object):
    """
    Const

    Constants to classify Unicode characters, returned by XCharacterClassification.getType()

    See Also:
        `API UnicodeType <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1i18n_1_1UnicodeType.html>`_
    """
    UNASSIGNED: Literal[0]
    UPPERCASE_LETTER: Literal[1]
    LOWERCASE_LETTER: Literal[2]
    TITLECASE_LETTER: Literal[3]
    MODIFIER_LETTER: Literal[4]
    OTHER_LETTER: Literal[5]
    NON_SPACING_MARK: Literal[6]
    ENCLOSING_MARK: Literal[7]
    COMBINING_SPACING_MARK: Literal[8]
    DECIMAL_DIGIT_NUMBER: Literal[9]
    LETTER_NUMBER: Literal[10]
    OTHER_NUMBER: Literal[11]
    SPACE_SEPARATOR: Literal[12]
    LINE_SEPARATOR: Literal[13]
    PARAGRAPH_SEPARATOR: Literal[14]
    CONTROL: Literal[15]
    FORMAT: Literal[16]
    PRIVATE_USE: Literal[17]
    SURROGATE: Literal[18]
    DASH_PUNCTUATION: Literal[19]
    INITIAL_PUNCTUATION: Literal[20]
    FINAL_PUNCTUATION: Literal[21]
    CONNECTOR_PUNCTUATION: Literal[22]
    OTHER_PUNCTUATION: Literal[23]
    MATH_SYMBOL: Literal[24]
    CURRENCY_SYMBOL: Literal[25]
    MODIFIER_SYMBOL: Literal[26]
    OTHER_SYMBOL: Literal[27]
    START_PUNCTUATION: Literal[28]
    END_PUNCTUATION: Literal[29]
    GENERAL_TYPES_COUNT: Literal[30]




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.inspection
from ...inspection.x_property_handler import XPropertyHandler as XPropertyHandler_3e950fbf

class EventHandler(XPropertyHandler_3e950fbf):
    """
    Service Class

    implements a property handler for use with a com.sun.star.inspection.ObjectInspector which, for a com.sun.star.form.FormComponent, provides the script events offered by this form component.
    
    For this, the parent of the form component, which by definition supports the com.sun.star.form.FormComponent service, is examined for the com.sun.star.script.XEventAttacherManager interface.

    See Also:
        `API EventHandler <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1inspection_1_1EventHandler.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.office
from typing_extensions import Literal
import typing
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..lang.x_component import XComponent as XComponent_98dc0ab5
if typing.TYPE_CHECKING:
    from ..geometry.real_point2_d import RealPoint2D as RealPoint2D_d6e70c78
    from ..geometry.real_size2_d import RealSize2D as RealSize2D_ca1a0c09
    from ..text.x_text import XText as XText_690408ca
    from ..util.date_time import DateTime as DateTime_84de09d3

class XAnnotation(XPropertySet_bc180bfa, XComponent_98dc0ab5):
    """
    This interface gives access to an annotation inside a document.

    See Also:
        `API XAnnotation <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1office_1_1XAnnotation.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.office.XAnnotation']

    @property
    def Anchor(self) -> object:
        """
        a reference to the document content this annotation is anchored to.
        """

    @property
    def Author(self) -> str:
        """
        stores the full name of the author who created this annotation.
        """

    @property
    def DateTime(self) -> 'DateTime_84de09d3':
        """
        stores the date and time this annotation was last edited.
        """

    @property
    def Initials(self) -> str:
        """
        stores the initials of the author who created this annotation.
        """

    @property
    def Position(self) -> 'RealPoint2D_d6e70c78':
        """
        this is an optional position that gives the user interface a hint where the annotation should be rendered.
        
        This could be an offset to the annotations anchor.
        """

    @property
    def Size(self) -> 'RealSize2D_ca1a0c09':
        """
        this is an optional size that gives the user interface a hint how large the annotation should be rendered.
        """

    @property
    def TextRange(self) -> 'XText_690408ca':
        """
        gives access to the annotations text.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form.component
from ...awt.uno_control_image_control_model import UnoControlImageControlModel as UnoControlImageControlModel_7b36111c
from ..data_aware_control_model import DataAwareControlModel as DataAwareControlModel_27110ef8
from ..x_image_producer_supplier import XImageProducerSupplier as XImageProducerSupplier_37df0f8f

class DatabaseImageControl(UnoControlImageControlModel_7b36111c, DataAwareControlModel_27110ef8, XImageProducerSupplier_37df0f8f):
    """
    Service Class

    specifies the model of a control used for displaying images stored in a database.
    
    As every com.sun.star.form.DataAwareControlModel, an image control can be bound to a database field. This means that for instance with every record change, the content of the database field is taken, interpreted as image, and displayed in the control.
    Unlike other more text-based controls, it does not interpret the content of the field as text or double, but as binary stream (see com.sun.star.sdb.XColumn.getBinaryStream()).
    
    Usually, an image control model can be bound to binary columns only, namely com.sun.star.sdbc.DataType.BINARY, com.sun.star.sdbc.DataType.VARBINARY, com.sun.star.sdbc.DataType.LONGVARBINARY, com.sun.star.sdbc.DataType.OTHER, com.sun.star.sdbc.DataType.LONGVARCHAR
    
    Note that besides taking the image to be displayed from the bound field, there is another option. The com.sun.star.awt.UnoControlImageControlModel.ImageURL property specifies the URL of an image to be displayed. If this property is changed from outside, the respective file is loaded and set as image source.
    
    In a usual data form, the scenario will be as follows:

    See Also:
        `API DatabaseImageControl <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1component_1_1DatabaseImageControl.html>`_
    """
    @property
    def ReadOnly(self) -> bool:
        """
        indicates if it is possible to change the image being displayed.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.rendering
from typing_extensions import Literal
from ..uno.x_interface import XInterface as XInterface_8f010a43

class XBufferController(XInterface_8f010a43):
    """
    Interface providing access to double/multi-buffer facilities of screen devices.
    
    This interface provides methods to enable and control double/multi-buffering facilities on screen devices.
    
    **since**
    
        OOo 2.0

    See Also:
        `API XBufferController <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1rendering_1_1XBufferController.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.rendering.XBufferController']

    def createBuffers(self, nBuffers: int) -> int:
        """
        Create the given number of background buffers.
        
        There's one buffer implicitly available, which is the canvas surface itself. Thus, calling createBuffers(1) creates a double-buffered object.

        Raises:
            com.sun.star.lang.IllegalArgumentException: ``IllegalArgumentException``
        """
    def destroyBuffers(self) -> None:
        """
        Destroy all buffers generated via this object.
        """
    def showBuffer(self, bUpdateAll: bool) -> bool:
        """
        Switch the display to show the specified buffer.
        
        The method returns, when the switch is performed and the selected buffer is shown on screen, or immediately when an error occurs. If the switch was successful, subsequent render operations will be directed to the new backbuffer.
        
        Use this method if you need your screen display to be in sync with other things, e.g. sound playback.
        """
    def switchBuffer(self, bUpdateAll: bool) -> bool:
        """
        Schedule the display of the specified buffer.
        
        The method returns, when the switching of the buffer is successfully scheduled, or immediately when an error occurs. If the switch was successful, subsequent render operations will be directed to the new backbuffer. Note that, if the buffer switching is exceedingly slow, or the frequency of switchBuffer() is exceedingly high, the buffer scheduled for display here might become the current render target before it is fully displayed on screen. In this case, any rendering operation to this buffer will block, until it is safe to perform the operation without visible cluttering.
        
        Use this method if you favor maximal render speed, but don't necessarily require your screen display to be in sync with other things, e.g. sound playback.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.bridge.oleautomation
from ...uno.x_interface import XInterface as XInterface_8f010a43

class ApplicationRegistration(XInterface_8f010a43):
    """
    Service Class

    registers UNO objects as COM objects.
    
    That is, COM class factories are registered with COM at runtime. The required EXE server is the application which deploys this service. In order to access the factories by COM API functions, there need to be proper registry entries. This service does not provide for writing those entries.
    
    The instantiation of the registered objects can be carried out by any ordinary mechanism which is used in a certain language to create COM components. For example, CreateObject in Visual Basic, CoCreateInstance in C++.
    
    Currently only a factory for the service com.sun.star.lang.MultiServiceFactory is registered by this service. The CLSID is {82154420-0FBF-11d4-8313-005004526AB4} and the ProgId is com.sun.star.ServiceManager.
    
    ApplicationRegistration does not provide any particular interface because the UNO objects are registered while instantiating this service and deregistered if the implementation, which makes use of this service, is being released.

    See Also:
        `API ApplicationRegistration <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1bridge_1_1oleautomation_1_1ApplicationRegistration.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.deployment
from typing_extensions import Literal
import typing
from abc import ABC
if typing.TYPE_CHECKING:
    from ..container.x_enumeration import XEnumeration as XEnumeration_f2180daa
    from ..task.x_interaction_handler import XInteractionHandler as XInteractionHandler_bf80e51
    from ..xml.dom.x_element import XElement as XElement_a33d0ae9

class XUpdateInformationProvider(ABC):
    """
    Objects implementing this interface provide access to the xml root of one or more update information files for a given set of URLs.
    
    **since**
    
        OOo 2.2

    See Also:
        `API XUpdateInformationProvider <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1deployment_1_1XUpdateInformationProvider.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.deployment.XUpdateInformationProvider']

    def cancel(self) -> None:
        """
        interrupts a getUpdateInformation call and let's it return immediately.
        """
    def getUpdateInformation(self, repositories: 'typing.Tuple[str, ...]', extensionId: str) -> 'typing.Tuple[XElement_a33d0ae9, ...]':
        """
        get update information for a specific extension or all available information from a repository.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
    def getUpdateInformationEnumeration(self, repositories: 'typing.Tuple[str, ...]', extensionId: str) -> 'XEnumeration_f2180daa':
        """
        get update information for a specific extension or all available information from a repository.

        Raises:
            com.sun.star.uno.Exception: ``Exception``
        """
    def setInteractionHandler(self, handler: 'XInteractionHandler_bf80e51') -> None:
        """
        Sets an interaction handler to be used for further operations.
        
        A default interaction handler is available as service com.sun.star.task.InteractionHandler. The documentation of this service also contains further information about the interaction handler concept.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .rectangle import Rectangle as Rectangle_84b109e9
    from .x_dockable_window_listener import XDockableWindowListener as XDockableWindowListener_36b80f7f

class XDockableWindow(XInterface_8f010a43):
    """
    specifies the docking interface for a window component.
    
    A window can either be docked where it resides as a child window in an application frame window or it can be floating where it will reside in its own decorated top level window.

    See Also:
        `API XDockableWindow <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XDockableWindow.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XDockableWindow']

    def addDockableWindowListener(self, xListener: 'XDockableWindowListener_36b80f7f') -> None:
        """
        adds a docking listener to the object.
        
        only a single listener may be registered at any time.
        """
    def enableDocking(self, bEnable: bool) -> None:
        """
        enable or disable docking, docking is disabled by default
        """
    def isFloating(self) -> bool:
        """
        queries the current window state
        """
    def isInPopupMode(self) -> bool:
        """
        queries the current pop-up mode
        """
    def isLocked(self) -> bool:
        """
        queries the current locking state
        """
    def lock(self) -> None:
        """
        prevents the window from being undocked this has no effect if the window is floating
        """
    def removeDockableWindowListener(self, xListener: 'XDockableWindowListener_36b80f7f') -> None:
        """
        removes the specified docking listener from the object.
        """
    def setFloatingMode(self, bFloating: bool) -> None:
        """
        toggle between floating and docked state
        """
    def startPopupMode(self, WindowRect: 'Rectangle_84b109e9') -> None:
        """
        shows the window in a menu like style, i.e.
        
        without decoration a special indicator will allow for tearing off the window see com.sun.star.awt.XDockableWindowListener for the corresponding events
        """
    def unlock(self) -> None:
        """
        enables undocking this has no effect if the window is floating
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.drawing
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing
from .homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine_1c250ebe


class HomogenMatrix(object):
    """
    Struct Class

    specifies a homogeneous matrix by three homogeneous lines

    See Also:
        `API HomogenMatrix <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1drawing_1_1HomogenMatrix.html>`_
    """
    typeName: Literal['com.sun.star.drawing.HomogenMatrix']

    def __init__(self, Line1: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line2: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line3: typing.Optional[HomogenMatrixLine_1c250ebe] = ..., Line4: typing.Optional[HomogenMatrixLine_1c250ebe] = ...) -> None:
        """
        Constructor

        Arguments:
            Line1 (HomogenMatrixLine, optional): Line1 value.
            Line2 (HomogenMatrixLine, optional): Line2 value.
            Line3 (HomogenMatrixLine, optional): Line3 value.
            Line4 (HomogenMatrixLine, optional): Line4 value.
        """


    @property
    def Line1(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line2(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line3(self) -> HomogenMatrixLine_1c250ebe:
        ...


    @property
    def Line4(self) -> HomogenMatrixLine_1c250ebe:
        ...





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from typing_extensions import Literal
import typing
from .x_type_description import XTypeDescription as XTypeDescription_3c210fb1
if typing.TYPE_CHECKING:
    from .x_interface_member_type_description import XInterfaceMemberTypeDescription as XInterfaceMemberTypeDescription_52ea159a
    from ..uno.uik import Uik as Uik_4fac0783

class XInterfaceTypeDescription(XTypeDescription_3c210fb1):
    """
    Reflects an interface type.
    
    This type is superseded by XInterfaceTypeDescription2, which supports multiple inheritance.

    See Also:
        `API XInterfaceTypeDescription <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1reflection_1_1XInterfaceTypeDescription.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.reflection.XInterfaceTypeDescription']

    def getBaseType(self) -> 'XTypeDescription_3c210fb1':
        """
        Returns the base interface or null, if the reflected interface is not inherited from another.
        
        This method is deprecated, as it only supports single inheritance. See XInterfaceTypeDescription2 for a replacement that supports multiple inheritance.
        """
    def getMembers(self) -> 'typing.Tuple[XInterfaceMemberTypeDescription_52ea159a, ...]':
        """
        Returns the members of the interfaces, i.e.
        
        attributes and methods.
        """
    def getUik(self) -> 'Uik_4fac0783':
        """
        Deprecated.
        
        UIK are not used anymore, a type is uniquely identified by its name.
        Returns the UIK, i.e. the unique identifier of the interface.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.document
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .cmis_property import CmisProperty as CmisProperty_e47d0d58
    from .cmis_version import CmisVersion as CmisVersion_d71c0cd9

class XCmisDocument(XInterface_8f010a43):
    """
    The document can provide access to CMIS properties and versions through this interface.

    See Also:
        `API XCmisDocument <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1document_1_1XCmisDocument.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.document.XCmisDocument']

    def canCancelCheckOut(self) -> bool:
        """
        """
    def canCheckIn(self) -> bool:
        """
        """
    def canCheckOut(self) -> bool:
        """
        """
    def cancelCheckOut(self) -> None:
        """
        Cancel checked out document, this will discard all changes since check-out.
        """
    def checkIn(self, isMajor: bool, comment: str) -> None:
        """
        Creates a new version of the document from the private working copy.
        """
    def checkOut(self) -> None:
        """
        Check out the document into a private working copy on the server, and update the loaded document to reflect this change.
        """
    def getAllVersions(self) -> 'typing.Tuple[CmisVersion_d71c0cd9, ...]':
        """
        """
    def isVersionable(self) -> bool:
        """
        Tells whether a document can support versioning or not.
        """
    def updateCmisProperties(self, cmisProperties: 'typing.Tuple[CmisProperty_e47d0d58, ...]') -> None:
        """
        """
    @property
    def CmisProperties(self) -> 'typing.Tuple[CmisProperty_e47d0d58, ...]':
        """
        Contains the properties values named after their CMIS ID.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.awt
from typing_extensions import Literal
import typing
from ..uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .size import Size as Size_576707ef
    from .x_graphics import XGraphics as XGraphics_842309dd

class XView(XInterface_8f010a43):
    """
    makes it possible to attach an output device to the object.
    
    This kind of object is called view-object.

    See Also:
        `API XView <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1awt_1_1XView.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.awt.XView']

    def draw(self, nX: int, nY: int) -> None:
        """
        draws the object at the specified position.
        
        If the output should be clipped, the caller has to set the clipping region.
        """
    def getGraphics(self) -> 'XGraphics_842309dd':
        """
        returns the output device which was set using the method XView.setGraphics().
        """
    def getSize(self) -> 'Size_576707ef':
        """
        returns the size of the object in device units.
        
        A device must be set before.
        """
    def setGraphics(self, aDevice: 'XGraphics_842309dd') -> bool:
        """
        sets the output device.
        """
    def setZoom(self, fZoomX: float, fZoomY: float) -> None:
        """
        sets the zoom factor.
        
        The zoom factor only affects the content of the view, not the size.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from .._pyi.drawing.accessible_draw_document_view import AccessibleDrawDocumentView as AccessibleDrawDocumentView
from .._pyi.drawing.accessible_graph_control import AccessibleGraphControl as AccessibleGraphControl
from .._pyi.drawing.accessible_graphic_shape import AccessibleGraphicShape as AccessibleGraphicShape
from .._pyi.drawing.accessible_image_bullet import AccessibleImageBullet as AccessibleImageBullet
from .._pyi.drawing.accessible_ole_shape import AccessibleOLEShape as AccessibleOLEShape
from .._pyi.drawing.accessible_shape import AccessibleShape as AccessibleShape
from .._pyi.drawing.accessible_slide_view import AccessibleSlideView as AccessibleSlideView
from .._pyi.drawing.accessible_slide_view_object import AccessibleSlideViewObject as AccessibleSlideViewObject
from .._pyi.drawing.applet_shape import AppletShape as AppletShape
from .._pyi.drawing.background import Background as Background
from .._pyi.drawing.bezier_point import BezierPoint as BezierPoint
from .._pyi.drawing.bitmap_table import BitmapTable as BitmapTable
from .._pyi.drawing.bound_volume import BoundVolume as BoundVolume
from .._pyi.drawing.camera_geometry import CameraGeometry as CameraGeometry
from .._pyi.drawing.caption_shape import CaptionShape as CaptionShape
from .._pyi.drawing.closed_bezier_shape import ClosedBezierShape as ClosedBezierShape
from .._pyi.drawing.color_table import ColorTable as ColorTable
from .._pyi.drawing.connector_properties import ConnectorProperties as ConnectorProperties
from .._pyi.drawing.connector_shape import ConnectorShape as ConnectorShape
from .._pyi.drawing.control_shape import ControlShape as ControlShape
from .._pyi.drawing.coordinate_sequence import CoordinateSequence as CoordinateSequence
from .._pyi.drawing.coordinate_sequence_sequence import CoordinateSequenceSequence as CoordinateSequenceSequence
from .._pyi.drawing.custom_shape import CustomShape as CustomShape
from .._pyi.drawing.custom_shape_engine import CustomShapeEngine as CustomShapeEngine
from .._pyi.drawing.dash_table import DashTable as DashTable
from .._pyi.drawing.defaults import Defaults as Defaults
from .._pyi.drawing.direction3_d import Direction3D as Direction3D
from .._pyi.drawing.document_settings import DocumentSettings as DocumentSettings
from .._pyi.drawing.double_sequence import DoubleSequence as DoubleSequence
from .._pyi.drawing.double_sequence_sequence import DoubleSequenceSequence as DoubleSequenceSequence
from .._pyi.drawing.draw_page import DrawPage as DrawPage
from .._pyi.drawing.draw_pages import DrawPages as DrawPages
from .._pyi.drawing.drawing_document import DrawingDocument as DrawingDocument
from .._pyi.drawing.drawing_document_draw_view import DrawingDocumentDrawView as DrawingDocumentDrawView
from .._pyi.drawing.drawing_document_factory import DrawingDocumentFactory as DrawingDocumentFactory
from .._pyi.drawing.ellipse_shape import EllipseShape as EllipseShape
from .._pyi.drawing.enhanced_custom_shape_adjustment_value import EnhancedCustomShapeAdjustmentValue as EnhancedCustomShapeAdjustmentValue
from .._pyi.drawing.enhanced_custom_shape_extrusion import EnhancedCustomShapeExtrusion as EnhancedCustomShapeExtrusion
from .._pyi.drawing.enhanced_custom_shape_geometry import EnhancedCustomShapeGeometry as EnhancedCustomShapeGeometry
from .._pyi.drawing.enhanced_custom_shape_handle import EnhancedCustomShapeHandle as EnhancedCustomShapeHandle
from .._pyi.drawing.enhanced_custom_shape_parameter import EnhancedCustomShapeParameter as EnhancedCustomShapeParameter
from .._pyi.drawing.enhanced_custom_shape_parameter_pair import EnhancedCustomShapeParameterPair as EnhancedCustomShapeParameterPair
from .._pyi.drawing.enhanced_custom_shape_path import EnhancedCustomShapePath as EnhancedCustomShapePath
from .._pyi.drawing.enhanced_custom_shape_segment import EnhancedCustomShapeSegment as EnhancedCustomShapeSegment
from .._pyi.drawing.enhanced_custom_shape_text_frame import EnhancedCustomShapeTextFrame as EnhancedCustomShapeTextFrame
from .._pyi.drawing.enhanced_custom_shape_text_path import EnhancedCustomShapeTextPath as EnhancedCustomShapeTextPath
from .._pyi.drawing.fill_properties import FillProperties as FillProperties
from .._pyi.drawing.flag_sequence import FlagSequence as FlagSequence
from .._pyi.drawing.flag_sequence_sequence import FlagSequenceSequence as FlagSequenceSequence
from .._pyi.drawing.generic_draw_page import GenericDrawPage as GenericDrawPage
from .._pyi.drawing.generic_drawing_document import GenericDrawingDocument as GenericDrawingDocument
from .._pyi.drawing.glue_point import GluePoint as GluePoint
from .._pyi.drawing.glue_point2 import GluePoint2 as GluePoint2
from .._pyi.drawing.gradient_table import GradientTable as GradientTable
from .._pyi.drawing.graphic_export_filter import GraphicExportFilter as GraphicExportFilter
from .._pyi.drawing.graphic_filter_request import GraphicFilterRequest as GraphicFilterRequest
from .._pyi.drawing.graphic_object_shape import GraphicObjectShape as GraphicObjectShape
from .._pyi.drawing.group_shape import GroupShape as GroupShape
from .._pyi.drawing.hatch import Hatch as Hatch
from .._pyi.drawing.hatch_table import HatchTable as HatchTable
from .._pyi.drawing.homogen_matrix import HomogenMatrix as HomogenMatrix
from .._pyi.drawing.homogen_matrix3 import HomogenMatrix3 as HomogenMatrix3
from .._pyi.drawing.homogen_matrix4 import HomogenMatrix4 as HomogenMatrix4
from .._pyi.drawing.homogen_matrix_line import HomogenMatrixLine as HomogenMatrixLine
from .._pyi.drawing.homogen_matrix_line3 import HomogenMatrixLine3 as HomogenMatrixLine3
from .._pyi.drawing.homogen_matrix_line4 import HomogenMatrixLine4 as HomogenMatrixLine4
from .._pyi.drawing.layer import Layer as Layer
from .._pyi.drawing.layer_manager import LayerManager as LayerManager
from .._pyi.drawing.line_dash import LineDash as LineDash
from .._pyi.drawing.line_properties import LineProperties as LineProperties
from .._pyi.drawing.line_shape import LineShape as LineShape
from .._pyi.drawing.marker_table import MarkerTable as MarkerTable
from .._pyi.drawing.master_page import MasterPage as MasterPage
from .._pyi.drawing.master_pages import MasterPages as MasterPages
from .._pyi.drawing.measure_properties import MeasureProperties as MeasureProperties
from .._pyi.drawing.measure_shape import MeasureShape as MeasureShape
from .._pyi.drawing.module_dispatcher import ModuleDispatcher as ModuleDispatcher
from .._pyi.drawing.ole2_shape import OLE2Shape as OLE2Shape
from .._pyi.drawing.open_bezier_shape import OpenBezierShape as OpenBezierShape
from .._pyi.drawing.page_shape import PageShape as PageShape
from .._pyi.drawing.plugin_shape import PluginShape as PluginShape
from .._pyi.drawing.point_sequence import PointSequence as PointSequence
from .._pyi.drawing.point_sequence_sequence import PointSequenceSequence as PointSequenceSequence
from .._pyi.drawing.poly_line_shape import PolyLineShape as PolyLineShape
from .._pyi.drawing.poly_polygon_bezier_coords import PolyPolygonBezierCoords as PolyPolygonBezierCoords
from .._pyi.drawing.poly_polygon_bezier_descriptor import PolyPolygonBezierDescriptor as PolyPolygonBezierDescriptor
from .._pyi.drawing.poly_polygon_bezier_shape import PolyPolygonBezierShape as PolyPolygonBezierShape
from .._pyi.drawing.poly_polygon_descriptor import PolyPolygonDescriptor as PolyPolygonDescriptor
from .._pyi.drawing.poly_polygon_shape import PolyPolygonShape as PolyPolygonShape
from .._pyi.drawing.poly_polygon_shape3_d import PolyPolygonShape3D as PolyPolygonShape3D
from .._pyi.drawing.position3_d import Position3D as Position3D
from .._pyi.drawing.qr_code import QRCode as QRCode
from .._pyi.drawing.rectangle_shape import RectangleShape as RectangleShape
from .._pyi.drawing.rotation_descriptor import RotationDescriptor as RotationDescriptor
from .._pyi.drawing.shadow_properties import ShadowProperties as ShadowProperties
from .._pyi.drawing.shape import Shape as Shape
from .._pyi.drawing.shape_collection import ShapeCollection as ShapeCollection
from .._pyi.drawing.shapes import Shapes as Shapes
from .._pyi.drawing.slide_renderer import SlideRenderer as SlideRenderer
from .._pyi.drawing.slide_sorter import SlideSorter as SlideSorter
from .._pyi.drawing.text import Text as Text
from .._pyi.drawing.text_properties import TextProperties as TextProperties
from .._pyi.drawing.text_shape import TextShape as TextShape
from .._pyi.drawing.transparency_gradient_table import TransparencyGradientTable as TransparencyGradientTable
from .._pyi.drawing.x_connectable_shape import XConnectableShape as XConnectableShape
from .._pyi.drawing.x_connector_shape import XConnectorShape as XConnectorShape
from .._pyi.drawing.x_control_shape import XControlShape as XControlShape
from .._pyi.drawing.x_custom_shape_engine import XCustomShapeEngine as XCustomShapeEngine
from .._pyi.drawing.x_custom_shape_handle import XCustomShapeHandle as XCustomShapeHandle
from .._pyi.drawing.x_draw_page import XDrawPage as XDrawPage
from .._pyi.drawing.x_draw_page_duplicator import XDrawPageDuplicator as XDrawPageDuplicator
from .._pyi.drawing.x_draw_page_expander import XDrawPageExpander as XDrawPageExpander
from .._pyi.drawing.x_draw_page_summarizer import XDrawPageSummarizer as XDrawPageSummarizer
from .._pyi.drawing.x_draw_page_supplier import XDrawPageSupplier as XDrawPageSupplier
from .._pyi.drawing.x_draw_pages import XDrawPages as XDrawPages
from .._pyi.drawing.x_draw_pages_supplier import XDrawPagesSupplier as XDrawPagesSupplier
from .._pyi.drawing.x_draw_sub_controller import XDrawSubController as XDrawSubController
from .._pyi.drawing.x_draw_view import XDrawView as XDrawView
from .._pyi.drawing.x_enhanced_custom_shape_defaulter import XEnhancedCustomShapeDefaulter as XEnhancedCustomShapeDefaulter
from .._pyi.drawing.x_glue_points_supplier import XGluePointsSupplier as XGluePointsSupplier
from .._pyi.drawing.x_graphic_export_filter import XGraphicExportFilter as XGraphicExportFilter
from .._pyi.drawing.x_layer import XLayer as XLayer
from .._pyi.drawing.x_layer_manager import XLayerManager as XLayerManager
from .._pyi.drawing.x_layer_supplier import XLayerSupplier as XLayerSupplier
from .._pyi.drawing.x_master_page_target import XMasterPageTarget as XMasterPageTarget
from .._pyi.drawing.x_master_pages_supplier import XMasterPagesSupplier as XMasterPagesSupplier
from .._pyi.drawing.x_presenter_helper import XPresenterHelper as XPresenterHelper
from .._pyi.drawing.x_selection_function import XSelectionFunction as XSelectionFunction
from .._pyi.drawing.x_shape import XShape as XShape
from .._pyi.drawing.x_shape_aligner import XShapeAligner as XShapeAligner
from .._pyi.drawing.x_shape_arranger import XShapeArranger as XShapeArranger
from .._pyi.drawing.x_shape_binder import XShapeBinder as XShapeBinder
from .._pyi.drawing.x_shape_combiner import XShapeCombiner as XShapeCombiner
from .._pyi.drawing.x_shape_descriptor import XShapeDescriptor as XShapeDescriptor
from .._pyi.drawing.x_shape_group import XShapeGroup as XShapeGroup
from .._pyi.drawing.x_shape_grouper import XShapeGrouper as XShapeGrouper
from .._pyi.drawing.x_shape_mirror import XShapeMirror as XShapeMirror
from .._pyi.drawing.x_shapes import XShapes as XShapes
from .._pyi.drawing.x_shapes2 import XShapes2 as XShapes2
from .._pyi.drawing.x_shapes3 import XShapes3 as XShapes3
from .._pyi.drawing.x_slide_preview_cache import XSlidePreviewCache as XSlidePreviewCache
from .._pyi.drawing.x_slide_preview_cache_listener import XSlidePreviewCacheListener as XSlidePreviewCacheListener
from .._pyi.drawing.x_slide_renderer import XSlideRenderer as XSlideRenderer
from .._pyi.drawing.x_slide_sorter_base import XSlideSorterBase as XSlideSorterBase
from .._pyi.drawing.x_universal_shape_descriptor import XUniversalShapeDescriptor as XUniversalShapeDescriptor



# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.reflection
from ..container.x_hierarchical_name_access import XHierarchicalNameAccess as XHierarchicalNameAccess_9e2611b5
from ..container.x_set import XSet as XSet_90c40a4f
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from .x_type_description_enumeration_access import XTypeDescriptionEnumerationAccess as XTypeDescriptionEnumerationAccess_8417168a

class TypeDescriptionManager(XHierarchicalNameAccess_9e2611b5, XSet_90c40a4f, XComponent_98dc0ab5, XTypeDescriptionEnumerationAccess_8417168a):
    """
    Service Class

    This service manages type descriptions and acts as a central access point to every type description.
    
    It delegates calls for demanded types to subsequent com.sun.star.reflection.TypeDescriptionProviders and may cache type descriptions.
    Using cppuhelper's bootstrapping routines bootstrapping an initial component context, there is a singleton accessible via key \"/singletons/com.sun.star.reflection.theTypeDescriptionManager\". This singleton object is hooked into the C UNO runtime typelib and lives until the context is shut down.
    
    **since**
    
        OOo 1.1.2

    See Also:
        `API TypeDescriptionManager <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1reflection_1_1TypeDescriptionManager.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.container
from typing_extensions import Literal
import typing
from .x_element_access import XElementAccess as XElementAccess_cd60e3f

class XNameAccess(XElementAccess_cd60e3f):
    """
    is used to access named objects within a container.
    
    To implement inaccurate name access, support the com.sun.star.beans.XExactName interface.

    See Also:
        `API XNameAccess <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1container_1_1XNameAccess.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.container.XNameAccess']

    def getByName(self, aName: str) -> object:
        """

        Raises:
            com.sun.star.container.NoSuchElementException: ``NoSuchElementException``
            com.sun.star.lang.WrappedTargetException: ``WrappedTargetException``
        """
    def getElementNames(self) -> 'typing.Tuple[str, ...]':
        """
        The order of the names is not specified.
        """
    def hasByName(self, aName: str) -> bool:
        """
        In many cases the next call is XNameAccess.getByName(). You should optimize this case.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Struct Class
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.frame.status
# Libre Office Version: 7.2
from typing_extensions import Literal
import typing


class Verb(object):
    """
    Struct Class

    describes a command that can be send to an OLE object
    
    For example, this can be used to select a font.
    
    **since**
    
        OOo 2.0

    See Also:
        `API Verb <https://api.libreoffice.org/docs/idl/ref/structcom_1_1sun_1_1star_1_1frame_1_1status_1_1Verb.html>`_
    """
    typeName: Literal['com.sun.star.frame.status.Verb']

    def __init__(self, VerbId: typing.Optional[int] = ..., VerbName: typing.Optional[str] = ..., VerbIsOnMenu: typing.Optional[bool] = ..., VerbIsConst: typing.Optional[bool] = ...) -> None:
        """
        Constructor

        Arguments:
            VerbId (int, optional): VerbId value.
            VerbName (str, optional): VerbName value.
            VerbIsOnMenu (bool, optional): VerbIsOnMenu value.
            VerbIsConst (bool, optional): VerbIsConst value.
        """


    @property
    def VerbId(self) -> int:
        """
        specifies the Id of the command.
        """


    @property
    def VerbName(self) -> str:
        """
        specifies the name of the command.
        
        The name is localized.
        """


    @property
    def VerbIsOnMenu(self) -> bool:
        """
        specifies if the command should be visible in a menu.
        """


    @property
    def VerbIsConst(self) -> bool:
        """
        specifies if the command is available for a constant object.
        """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.sdb
from typing_extensions import Literal
import typing
from ..task.x_interaction_continuation import XInteractionContinuation as XInteractionContinuation_5af0108e
if typing.TYPE_CHECKING:
    from ..beans.property_value import PropertyValue as PropertyValue_c9610c73

class XInteractionSupplyParameters(XInteractionContinuation_5af0108e):
    """
    An interaction continuation handing back parameter data.
    
    This continuation is typically used in conjunction with a com.sun.star.sdb.ParametersRequest.

    See Also:
        `API XInteractionSupplyParameters <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1sdb_1_1XInteractionSupplyParameters.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.sdb.XInteractionSupplyParameters']

    def setParameters(self, Values: 'typing.Tuple[PropertyValue_c9610c73, ...]') -> None:
        """
        set the parameters chosen by the interaction handler
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.datatransfer.dnd
from typing_extensions import Literal
import typing
from ...uno.x_interface import XInterface as XInterface_8f010a43
if typing.TYPE_CHECKING:
    from .x_drop_target_listener import XDropTargetListener as XDropTargetListener_d62c1305

class XDropTarget(XInterface_8f010a43):
    """
    This interface is implemented by a view or window that supports drop operations.
    
    Differently to Java, the association between view and interface is fixed and cannot be changed. Otherwise, the AWT messaging would have to be implemented for any window supporting Drag and Drop operations, which would be a performance issue.

    See Also:
        `API XDropTarget <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1datatransfer_1_1dnd_1_1XDropTarget.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.datatransfer.dnd.XDropTarget']

    def addDropTargetListener(self, dtl: 'XDropTargetListener_d62c1305') -> None:
        """
        Add a DropTargetListener.
        
        The listener will be queried for the XAutoscroll interface to see if it supports autoscrolling.
        """
    def getDefaultActions(self) -> int:
        """
        Determine the actions supported by a drop target.
        
        By default this will include all drag and drop actions.
        """
    def isActive(self) -> bool:
        """
        Indicates either a drop target object is active or not.
        """
    def removeDropTargetListener(self, dtl: 'XDropTargetListener_d62c1305') -> None:
        """
        Remove a drop target listener.
        """
    def setActive(self, active: bool) -> None:
        """
        Sets the drop target object active or inactive.
        
        A value of FALSE sets the drop target object inactive.
        """
    def setDefaultActions(self, actions: int) -> None:
        """
        Sets the default acceptable actions for this drop target.
        
        This method is a way to reduce the number of Drag and Drop events by blocking events for actions not supported by this target.
        
        By default the listener will receive notifications for all actions.
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Enum
# this is a auto generated file generated by Cheetah
# Namespace: com.sun.star.ucb
# Libre Office Version: 7.2
from typing import TYPE_CHECKING
if TYPE_CHECKING:
    import uno
"""
Enum



See Also:
    `API ContentCreationError <https://api.libreoffice.org/docs/idl/ref/namespacecom_1_1sun_1_1star_1_1ucb.html#aa2e437022c4d519cf5488a06e5e81ef4>`_
"""

CONTENT_CREATION_FAILED: 'uno.Enum'
"""
Provider was unable to create the content instance.
"""
IDENTIFIER_CREATION_FAILED: 'uno.Enum'
"""
Creation of content identifier failed.
"""
NO_CONTENT_BROKER: 'uno.Enum'
"""
"""
NO_CONTENT_PROVIDER: 'uno.Enum'
"""
No Content Provider for given content identifier available.
"""
NO_IDENTIFIER_FACTORY: 'uno.Enum'
"""
"""
UNKNOWN: 'uno.Enum'
"""
Unknown.

An unknown I/O error has occurred.
"""




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.text
from .text_range import TextRange as TextRange_90540a5f
from ..util.x_sortable import XSortable as XSortable_8ff20a5a
from ..beans.x_multi_property_states import XMultiPropertyStates as XMultiPropertyStates_2a3e0f4d
from ..beans.x_property_set import XPropertySet as XPropertySet_bc180bfa
from ..beans.x_property_state import XPropertyState as XPropertyState_d55c0ccf
from ..document.x_document_insertable import XDocumentInsertable as XDocumentInsertable_4b911007
from .x_paragraph_cursor import XParagraphCursor as XParagraphCursor_e2fa0d39
from .x_sentence_cursor import XSentenceCursor as XSentenceCursor_d6590cd8
from .x_text_cursor import XTextCursor as XTextCursor_a60c0b48
from .x_word_cursor import XWordCursor as XWordCursor_a5e40b3f

class TextCursor(TextRange_90540a5f, XSortable_8ff20a5a, XSentenceCursor_d6590cd8, XParagraphCursor_e2fa0d39, XWordCursor_a5e40b3f, XTextCursor_a60c0b48, XPropertySet_bc180bfa, XPropertyState_d55c0ccf, XMultiPropertyStates_2a3e0f4d, XDocumentInsertable_4b911007):
    """
    Service Class

    A TextCursor is a TextRange which can be moved within a Text object.

    See Also:
        `API TextCursor <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1text_1_1TextCursor.html>`_
    """





# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Interface Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.ui.dialogs
from typing_extensions import Literal
import typing
from .x_file_picker import XFilePicker as XFilePicker_ec3e0d2d

class XFilePicker2(XFilePicker_ec3e0d2d):
    """
    extends file picker interface to workaround some design problems.

    See Also:
        `API XFilePicker2 <https://api.libreoffice.org/docs/idl/ref/interfacecom_1_1sun_1_1star_1_1ui_1_1dialogs_1_1XFilePicker2.html>`_
    """
    __pyunointerface__: Literal['com.sun.star.ui.dialogs.XFilePicker2']

    def getSelectedFiles(self) -> 'typing.Tuple[str, ...]':
        """
        Returns a sequence of the selected files including path information in URL format, conforming to Rfc1738.
        
        If the user closed the dialog with cancel an empty sequence will be returned.
        
        If the user closed the dialog with OK a list of all selected files will be returned.
        
        Instead to the method getFiles() of base interface XFilePicker the new method return full qualified URLs for every selected file.
        
        A list of all selected file as complete URLs.
        
        Notes for the implementation of a FileSave dialog:If there exists a checkbox \"Automatic File Extension\" which is checked and a valid filter is currently selected the dialog may automatically add an extension to the selected file name(s).
        """




# coding: utf-8
#
# Copyright 2022 :Barry-Thomas-Paul: Moss
#
# Licensed under the Apache License, Version 2.0 (the "License")
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http: // www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Service Class
# this is a auto generated file generated by Cheetah
# Libre Office Version: 7.2
# Namespace: com.sun.star.form
from ..awt.x_tab_controller import XTabController as XTabController_bacd0be7
from ..container.x_child import XChild as XChild_a6390b07
from ..container.x_enumeration_access import XEnumerationAccess as XEnumerationAccess_4bac0ffc
from .form_controller_dispatcher import FormControllerDispatcher as FormControllerDispatcher_5b3a107b
from .x_confirm_delete_broadcaster import XConfirmDeleteBroadcaster as XConfirmDeleteBroadcaster_6772109f
from .x_database_parameter_broadcaster import XDatabaseParameterBroadcaster as XDatabaseParameterBroadcaster_ac7f1234
from .x_form_controller import XFormController as XFormController_d4fc0ccc
from ..lang.x_component import XComponent as XComponent_98dc0ab5
from ..sdb.x_row_set_approve_broadcaster import XRowSetApproveBroadcaster as XRowSetApproveBroadcaster_56601044
from ..sdb.xsql_error_broadcaster import XSQLErrorBroadcaster as XSQLErrorBroadcaster_4d10dfd
from ..util.x_modify_broadcaster import XModifyBroadcaster as XModifyBroadcaster_fd990df0

class FormController(FormControllerDispatcher_5b3a107b, XConfirmDeleteBroadcaster_6772109f, XDatabaseParameterBroadcaster_ac7f1234, XFormController_d4fc0ccc, XTabController_bacd0be7, XChild_a6390b07, XEnumerationAccess_4bac0ffc, XComponent_98dc0ab5, XRowSetApproveBroadcaster_56601044, XSQLErrorBroadcaster_4d10dfd, XModifyBroadcaster_fd990df0):
    """
    Service Class

    is superseded by com.sun.star.form.runtime.FormController.
    
    .. deprecated::
    
        Class is deprecated.

    See Also:
        `API FormController <https://api.libreoffice.org/docs/idl/ref/servicecom_1_1sun_1_1star_1_1form_1_1FormController.html>`_
    """


